# x-manger

![PyPI version](https://img.shields.io/pypi/v/x-manger.svg)
[![Documentation Status](https://readthedocs.org/projects/x-manger/badge/?version=latest)](https://x-manger.readthedocs.io/en/latest/?version=latest)

 **x-manger** provides a unified, production-ready interface for all file management operations in Python applications. Handle data, cache, temp files, archives, and logging through a single, intuitive API.

* PyPI package: https://pypi.org/project/x-manger/
* Free software: MIT License
* Documentation: https://x-manger.readthedocs.io.

## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyfeldroy/cookiecutter) and the [audreyfeldroy/cookiecutter-pypackage](https://github.com/audreyfeldroy/cookiecutter-pypackage) project template.
